import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', // User
  'a08a1080b88344b0c8a7/', // Id of the Gist
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', // commit
  'iris.csv', // File name
].join('');

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

// Add SVG in the HTML body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  //Loading data from CSV URI
  const data = await csv(csvUrl, parseRow);
  //declaring colors for scatter plot legends
  const color = d3
    .scaleOrdinal()
    .domain(['setosa', 'versicolor', 'virginica'])
    .range([
      '#440154ff',
      '#21908dff',
      '#fde725ff',
    ]);

  //declaring legends for scatter plot
  const legend = svg
    .selectAll('legend')
    .data(color.domain())
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', function (d, i) {
      return 'translate(0,' + i * 20 + ')';
    });

  //Appending colors to legends
  legend
    .append('rect')
    .attr('x', width - 20)
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', color);

  //Appending text to legends
  legend
    .append('text')
    .attr('x', width - 26)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .attr(
      'font-family',
      'Arial, Helvetica, sans-serif'
    )
    .text(function (d) {
      return d;
    });

  //Creating new scatterPlot object from helper fucntion
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(data)
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 130,
      bottom: 60,
      left: 70,
    })
    .radius(5);
  	// Appending y label to the svg 
    svg.append("text")
    .attr("class", "y label")
    .attr("text-anchor", "end")
    .attr("y", 10)
    .attr("dy", ".65em")
    .attr("dx", "-5.65em")
    .attr("transform", "rotate(-90)")
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text("sepal_length");
  	// Appending x label to the svg 
    svg.append("text")
    .attr("class", "x label")
    .attr("text-anchor", "end")
    .attr("x", width-450)
    .attr("y", height-10)
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text("petal_width"); 
  
  //Appending plot scatter plot to svg html
  svg.call(plot);
  //declaring colmns from data file
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];

  //Changing scatter plot x axis by a time interval
  let i = 0;
  setInterval(() => {
    plot.xValue(
      (d) => d[columns[i % columns.length]]
    );
  	// removing x label to the svg 
  	svg.select(".x.label").remove()
  	// appending again x label to the svg cuz to change petal width
    svg.append("text")
    .attr("class", "x label")
    .attr("text-anchor", "end")
    .attr("x", width-450)
    .attr("y", height-10)
    .attr("fill", "Blue")
    .attr("font-size", "30px")
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text(columns[i % columns.length]);     
    svg.call(plot);
    i++;
  }, 1500);
};
main();
